@@ -17,7 +17,7 @@
 
 package Git::Hooks::CheckJira;
 {
-  $Git::Hooks::CheckJira::VERSION = '0.032';
+  $Git::Hooks::CheckJira::VERSION = '0.033';
 }
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
 
@@ -60,8 +60,8 @@ sub _setup_config {
 sub grok_msg_jiras {
     my ($git, $msg) = @_;
 
-    my $matchkey = $git->config($CFG => 'matchkey');
-    my $matchlog = $git->config($CFG => 'matchlog');
+    my $matchkey = $git->get_config($CFG => 'matchkey');
+    my $matchlog = $git->get_config($CFG => 'matchlog');
 
     # Grok the JIRA issue keys from the commit log
     if ($matchlog) {
@@ -84,7 +84,7 @@ sub get_issue {
     unless (defined $JIRA) {
         my %jira;
         for my $option (qw/jiraurl jirauser jirapass/) {
-            $jira{$option} = $git->config($CFG => $option)
+            $jira{$option} = $git->get_config($CFG => $option)
                 or die "$PKG: Missing $CFG.$option configuration attribute.\n";
         }
         $jira{jiraurl} =~ s:/+$::; # trim trailing slashes from the URL
@@ -117,7 +117,7 @@ sub check_codes {
 
     my @codes;
 
-    foreach my $check ($git->config($CFG => 'check-code')) {
+    foreach my $check ($git->get_config($CFG => 'check-code')) {
         my $code;
         if ($check =~ s/^file://) {
             $code = do $check;
@@ -146,13 +146,13 @@ sub check_commit_msg {
 
     # Filter out JIRAs not belonging to any of the specific projects,
     # if any. We don't care about them.
-    if (my @projects = $git->config($CFG => 'project')) {
+    if (my @projects = $git->get_config($CFG => 'project')) {
         my %projects = map {($_ => undef)} @projects;
         @keys = grep {/([^-]+)/ && exists $projects{$1}} @keys;
     }
 
     unless (@keys) {
-        if ($git->config($CFG => 'require')) {
+        if ($git->get_config($CFG => 'require')) {
             my $shortid = substr $commit->{commit}, 0, 8;
             if (@keys == $nkeys) {
                 die <<"EOF";
@@ -160,7 +160,7 @@ $PKG: commit $shortid (in $ref) does not cite any JIRA in the message:
 $commit->{body}
 EOF
             } else {
-                my $project = join(' ', $git->config($CFG => 'project'));
+                my $project = join(' ', $git->get_config($CFG => 'project'));
                 die <<"EOF";
 $PKG: commit $shortid (in $ref) does not cite any JIRA from the expected
 $PKG: projects ($project) in the message:
@@ -174,8 +174,8 @@ EOF
 
     my @issues;
 
-    my $unresolved  = $git->config($CFG => 'unresolved');
-    my $by_assignee = $git->config($CFG => 'by-assignee');
+    my $unresolved  = $git->get_config($CFG => 'unresolved');
+    my $by_assignee = $git->get_config($CFG => 'by-assignee');
 
     foreach my $key (@keys) {
         my $issue = get_issue($git, $key);
@@ -210,7 +210,7 @@ sub check_message_file {
     _setup_config($git);
 
     my $current_branch = 'refs/heads/' . $git->get_current_branch();
-    return unless is_ref_enabled($current_branch, $git->config($CFG => 'ref'));
+    return unless is_ref_enabled($current_branch, $git->get_config($CFG => 'ref'));
 
     my $msg = read_file($commit_msg_file)
         or die "$PKG: Can't open file '$commit_msg_file' for reading: $!\n";
@@ -230,7 +230,7 @@ sub check_message_file {
 sub check_ref {
     my ($git, $ref) = @_;
 
-    return unless is_ref_enabled($ref, $git->config($CFG => 'ref'));
+    return unless is_ref_enabled($ref, $git->get_config($CFG => 'ref'));
 
     foreach my $commit ($git->get_affected_ref_commits($ref)) {
         check_commit_msg($git, $commit, $ref);
@@ -271,7 +271,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 DESCRIPTION
 
