@@ -1,12 +1,20 @@
 package Git::More;
 {
-  $Git::More::VERSION = '0.032';
+  $Git::More::VERSION = '0.033';
 }
-# ABSTRACT: An extension of App::gh::Git with some goodies for hook developers.
-use parent 'App::gh::Git';
+# ABSTRACT: A Git extension with some goodies for hook developers.
 
 use strict;
 use warnings;
+
+BEGIN {
+    # See http://git.661346.n2.nabble.com/better-way-to-find-Git-pm-officially-td7416362.html
+    local @INC = @INC;
+    unshift @INC, split(/:/, $ENV{GITPERLLIB}) if exists $ENV{GITPERLLIB};
+    require Git;
+    use parent -norequire, 'Git';
+}
+
 use Error qw(:try);
 use Carp;
 use Git::Hooks qw/:utils/;
@@ -105,7 +113,7 @@ sub _compatibilize_config {
 }
 
 sub get_config {
-    my ($git) = @_;
+    my ($git, $section, $var) = @_;
 
     unless (exists $git->{more}{config}) {
         my %config;
@@ -136,14 +144,17 @@ sub get_config {
         $git->{more}{config} = \%config;
     }
 
-    return $git->{more}{config};
-}
+    my $config = $git->{more}{config};
 
-sub config {
-    my ($git, $section, $var) = @_;
-    my $config = $git->get_config();
-    if (exists $config->{lc $section}{$var}) {
-        return wantarray ? @{$config->{lc $section}{$var}} : $config->{lc $section}{$var}[-1];
+    $section = lc $section if defined $section;
+
+    if (! defined $section) {
+        return $config;
+    } elsif (! defined $var) {
+        $config->{$section} = {} unless exists $config->{$section};
+        return $config->{$section};
+    } elsif (exists $config->{$section}{$var}) {
+        return wantarray ? @{$config->{$section}{$var}} : $config->{$section}{$var}[-1];
     } else {
         return wantarray ? () : undef;
     }
@@ -281,7 +292,7 @@ sub authenticated_user {
     my ($git) = @_;
 
     unless (exists $git->{more}{authenticated_user}) {
-        if (my $userenv = $git->config(githooks => 'userenv')) {
+        if (my $userenv = $git->get_config(githooks => 'userenv')) {
             if ($userenv =~ /^eval:(.*)/) {
                 $git->{more}{authenticated_user} = eval $1; ## no critic (BuiltinFunctions::ProhibitStringyEval)
                 die __PACKAGE__, ": error evaluating userenv value ($userenv): $@\n"
@@ -318,11 +329,11 @@ __END__
 
 =head1 NAME
 
-Git::More - An extension of App::gh::Git with some goodies for hook developers.
+Git::More - A Git extension with some goodies for hook developers.
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -340,21 +351,24 @@ version 0.032
 
 =head1 DESCRIPTION
 
-This is an extension of the C<App::gh::Git> class. It's meant to
-implement a few extra methods commonly needed by Git hook developers.
+This is an extension of the C<Git> class. It's meant to implement a
+few extra methods commonly needed by Git hook developers.
 
 In particular, it's used by the standard hooks implemented by the
 C<Git::Hooks> framework.
 
 =head1 METHODS
 
-=head2 get_config
+=head2 get_config [SECTION [VARIABLE]]
 
-This method groks the configuration options for the repository. It
-returns every option found by invoking C<git config --list>.
+This method groks the configuration options for the repository by
+invoking C<git config --list>. The configuration is cached during the
+first invokation in the object C<Git::More> object. So, if the
+configuration is changed afterwards, the method won't notice it. This
+is usually ok for hooks, though.
 
-The options are returned as a hash-ref pointing to a two-level
-hash. For example, if the config options are these:
+With no arguments, the options are returned as a hash-ref pointing to
+a two-level hash. For example, if the config options are these:
 
     section1.a=1
     section1.b=2
@@ -392,19 +406,30 @@ the last one being the local value.
 So, if you want to treat an option as single-valued, you should fetch
 it like this:
 
-     $h->{section1}{a}[-1]
-     $h->{'section2.x'}{a}[-1]
+    $h->{section1}{a}[-1]
+    $h->{'section2.x'}{a}[-1]
 
-=head2 config SECTION VARIABLE
+If the SECTION argument is passed, the method returns the second-level
+hash for it. So, following the example above, this call:
 
-This method fetches the configuration option SECTION.VARIABLE as a
-scalar or a list, depending on the context in which it was called.
+    $git->get_config('section1');
 
-In scalar context, if the option has more than one value, the last one
-is returned. If the option is undefined, it returns undef.
+This call would return this hash:
 
-In list context, all option values are returned in a list. If the
-option is undefined, it returns the empty list.
+    {
+        'a' => [1],
+        'b' => [2, 3],
+    }
+
+If the section don't exist an empty hash is returned. Any key/value
+added to the returned hash will be available in subsequent invokations
+of C<get_config>.
+
+If the VARIABLE argument is also passed, the method returns the
+value(s) of the configuration option C<SECTION.VARIABLE>. In list
+context the method returns the list of all values or the empty list,
+if the variable isn't defined. In scalar context, the method returns
+the variable's last value or C<undef>, if it's not defined.
 
 =head2 cache SECTION
 
@@ -505,7 +530,7 @@ it's usually sub-intended to reside under the 'refs/heads/' ref scope.
 
 =head1 SEE ALSO
 
-C<App::gh::Git>
+C<Git>
 
 =head1 AUTHOR
 
